--[[
	Persistent Data for RaidTracker, Saved Variables	
]]

KarmaData = {
	_store = {	
		db = nil;
		name = nil;
		defaults = { Options = nil };
	}
};

function KarmaData:_DataHookDB( )
	local s = self._store;
	if not s.name then return end
	
	-- init db and chain: self --> db --> defaults
	s.db = _G[s.name] or { }
	_G[s.name] = s.db
	for i,v in pairs(s.defaults) do
		if type(v) == "table"  then
			if not s.db[i] then	s.db[i] = { } end 
			setmetatable( s.db[i], { __index = s.defaults[i] } ); 	
		end
	end
	setmetatable( s.db, { __index = s.defaults } )
end 


function KarmaData:_DataOnVariablesLoaded( )
	self:_DataHookDB( );
	if self.RunVersionFix then 
		self:RunVersionFix()
	end;	
end


function KarmaData:RegisterDB( name, defaults )
	if not name then return end
	local s = self._store;
	
	s.name = name;
	s.defaults = defaults or s.defaults or { };
					
	self:_DataHookDB( );
end 


function KarmaData:ImportToDB( dbitem, src, prefix, isMerge, names )
	if not names or not src then return end
	local dst = self._store.db;
	local util = KarmaUtility;
	
	if dbitem then 
		if not dst[dbitem] then dst[dbitem] = { }  end
		dst = dst[dbitem];
	end

	for i,v in pairs(names) do
		local srcname = prefix..v
		if type(i) == "number" then i = v end
		
		if src[srcname] then
			util:SysMsg( "  importing ",srcname," to ",dbitem,":",i );
			if isMerge then
				util:MergeDeep( dst[i], src[srcname] );
			else
				dst[i] = util:CopyDeep( src[srcname] );
			end
		end
	end
end

